@@ -255,25 +255,25 @@ def scRFE (adata, classOfInterest, nEstimators = 5000, randomState = 0, min_cell
     results_df = pd.DataFrame()
 
     score_df = {}
-    for i in tqdm(range(len(adata.obs[classOfInterest]))[0:3]):
 
-        for labelOfInterest in np.unique(dataMatrix.obs[classOfInterest])[0:3]:
 
-            dataMatrix_labelOfInterest = dataMatrix.copy()
+    for labelOfInterest in np.unique(dataMatrix.obs[classOfInterest]):
 
-            feature_selected, feature_importance, model_score, X_new, y =  makeOneForest(dataMatrix = dataMatrix,
-                classOfInterest = classOfInterest, labelOfInterest = labelOfInterest,
-                nEstimators = nEstimators, randomState = randomState,  min_cells = min_cells,
-                    keep_small_categories = keep_small_categories,
-                       nJobs = nJobs, oobScore = oobScore, Step= Step, Cv=Cv, verbosity=verbosity)
+        dataMatrix_labelOfInterest = dataMatrix.copy()
 
-            results_df = resultWrite (classOfInterest, results_df,
-                                labelOfInterest = labelOfInterest,
-                        feature_selected = feature_selected,
-                        feature_importance = feature_importance)
+        feature_selected, feature_importance, model_score, X_new, y =  makeOneForest(dataMatrix = dataMatrix,
+            classOfInterest = classOfInterest, labelOfInterest = labelOfInterest,
+            nEstimators = nEstimators, randomState = randomState,  min_cells = min_cells,
+                keep_small_categories = keep_small_categories,
+                   nJobs = nJobs, oobScore = oobScore, Step= Step, Cv=Cv, verbosity=verbosity)
+
+        results_df = resultWrite (classOfInterest, results_df,
+                            labelOfInterest = labelOfInterest,
+                    feature_selected = feature_selected,
+                    feature_importance = feature_importance)
+
+        score_df[labelOfInterest] = model_score
 
-            score_df[labelOfInterest] = model_score
-        pass
 
     return results_df,score_df
 
